@@ -1,6 +1,8 @@
 use crate::error::RPCError;
 use ckb_dao::DaoCalculator;
-use ckb_jsonrpc_types::{Capacity, DryRunResult, OutPoint, Transaction};
+use ckb_jsonrpc_types::{
+    Capacity, DaoWithdrawingCalculationKind, DryRunResult, OutPoint, Transaction,
+};
 use ckb_shared::{shared::Shared, Snapshot};
 use ckb_store::ChainStore;
 use ckb_types::{
@@ -14,7 +16,6 @@ use ckb_types::{
     },
     packed,
     prelude::*,
-    H256,
 };
 use ckb_verification::{ScriptVerifier, TxVerifyEnv};
 use jsonrpc_core::Result;
@@ -112,14 +113,17 @@ pub trait ExperimentRpc {
     ///
     /// ## Params
     ///
-    /// * `out_point` - Reference to the DAO cell.
-    /// * `block_hash` - The assumed reference block for withdrawing. This block must be in the
-    /// [canonical chain](trait.ChainRpc.html#canonical-chain).
+    /// * `out_point` - Reference to the DAO cell, the depositing transaction's output.
+    /// * `kind` - Two kinds of dao withdrawal amount calculation option.
+    ///
+    /// option 1, the assumed reference block hash for withdrawing phase 1 transaction, this block must be in the
+    /// [canonical chain](trait.ChainRpc.html#canonical-chain), the calculation of occupied capacity will be based on the depositing transaction's output, assuming the output of phase 1 transaction is the same as the depositing transaction's output.
+    ///
+    /// option 2, the out point of the withdrawing phase 1 transaction, the calculation of occupied capacity will be based on corresponding phase 1 transaction's output.
     ///
     /// ## Returns
     ///
-    /// The RPC returns the final capacity when the cell `out_point` is withdrawn using the block
-    /// `block_hash` as the reference.
+    /// The RPC returns the final capacity when the cell `out_point` is withdrawn using the block hash or withdrawing phase 1 transaction out point as the reference.
     ///
     /// In CKB, scripts cannot get the information about in which block the transaction is
     /// committed. A workaround is letting the transaction reference a block hash so the script
@@ -162,7 +166,7 @@ pub trait ExperimentRpc {
     fn calculate_dao_maximum_withdraw(
         &self,
         out_point: OutPoint,
-        block_hash: H256,
+        kind: DaoWithdrawingCalculationKind,
     ) -> Result<Capacity>;
 }
 
@@ -179,34 +183,66 @@ impl ExperimentRpc for ExperimentRpcImpl {
     fn calculate_dao_maximum_withdraw(
         &self,
         out_point: OutPoint,
-        withdrawing_header_hash: H256,
+        kind: DaoWithdrawingCalculationKind,
     ) -> Result<Capacity> {
         let snapshot: &Snapshot = &self.shared.snapshot();
         let consensus = snapshot.consensus();
         let out_point: packed::OutPoint = out_point.into();
         let data_loader = snapshot.as_data_provider();
         let calculator = DaoCalculator::new(consensus, &data_loader);
+        match kind {
+            DaoWithdrawingCalculationKind::WithdrawingHeaderHash(withdrawing_header_hash) => {
+                let (tx, deposit_header_hash) = snapshot
+                    .get_transaction(&out_point.tx_hash())
+                    .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
+                let output = tx
+                    .outputs()
+                    .get(out_point.index().unpack())
+                    .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
+                let output_data = tx
+                    .outputs_data()
+                    .get(out_point.index().unpack())
+                    .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
 
-        let (tx, deposit_header_hash) = snapshot
-            .get_transaction(&out_point.tx_hash())
-            .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
-        let output = tx
-            .outputs()
-            .get(out_point.index().unpack())
-            .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
-        let output_data = tx
-            .outputs_data()
-            .get(out_point.index().unpack())
-            .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
+                match calculator.calculate_maximum_withdraw(
+                    &output,
+                    core::Capacity::bytes(output_data.len()).expect("should not overlfow"),
+                    &deposit_header_hash,
+                    &withdrawing_header_hash.pack(),
+                ) {
+                    Ok(capacity) => Ok(capacity.into()),
+                    Err(err) => Err(RPCError::from_ckb_error(err)),
+                }
+            }
+            DaoWithdrawingCalculationKind::WithdrawingOutPoint(withdrawing_out_point) => {
+                let (_tx, deposit_header_hash) = snapshot
+                    .get_transaction(&out_point.tx_hash())
+                    .ok_or_else(|| RPCError::invalid_params("invalid out_point"))?;
 
-        match calculator.calculate_maximum_withdraw(
-            &output,
-            core::Capacity::bytes(output_data.len()).expect("should not overlfow"),
-            &deposit_header_hash,
-            &withdrawing_header_hash.pack(),
-        ) {
-            Ok(capacity) => Ok(capacity.into()),
-            Err(err) => Err(RPCError::from_ckb_error(err)),
+                let withdrawing_out_point: packed::OutPoint = withdrawing_out_point.into();
+                let (withdrawing_tx, withdrawing_header_hash) = snapshot
+                    .get_transaction(&withdrawing_out_point.tx_hash())
+                    .ok_or_else(|| RPCError::invalid_params("invalid withdrawing_out_point"))?;
+
+                let output = withdrawing_tx
+                    .outputs()
+                    .get(withdrawing_out_point.index().unpack())
+                    .ok_or_else(|| RPCError::invalid_params("invalid withdrawing_out_point"))?;
+                let output_data = withdrawing_tx
+                    .outputs_data()
+                    .get(withdrawing_out_point.index().unpack())
+                    .ok_or_else(|| RPCError::invalid_params("invalid withdrawing_out_point"))?;
+
+                match calculator.calculate_maximum_withdraw(
+                    &output,
+                    core::Capacity::bytes(output_data.len()).expect("should not overlfow"),
+                    &deposit_header_hash,
+                    &withdrawing_header_hash,
+                ) {
+                    Ok(capacity) => Ok(capacity.into()),
+                    Err(err) => Err(RPCError::from_ckb_error(err)),
+                }
+            }
         }
     }
 }
