@@ -246,9 +246,7 @@ impl MinerRpc for MinerRpcImpl {
             None => None,
         };
 
-        let tx_pool = self.shared.tx_pool_controller();
-
-        tx_pool
+        self.shared
             .get_block_template(bytes_limit, proposals_limit, max_version.map(Into::into))
             .map_err(|err| {
                 error!("send get_block_template request error {}", err);
